@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2008-2021 Rumma & Ko Ltd
+# Copyright 2008-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 import os
@@ -285,7 +285,7 @@ class Albums(dd.Table):
 
 class FilesByAlbum(Files):
     master_key = "album"
-    display_mode = "gallery"
+    display_mode_main = "gallery"
     column_names = "file description thumbnail *"
 
 
@@ -323,8 +323,8 @@ class UsagesByController(FileUsages):
     label = _("Media files")
     master_key = 'owner'
     column_names = "seqno file file__thumbnail *"
-    display_mode = "gallery"
-    # display_mode = "summary"
+    display_mode_main = "gallery"
+    # display_mode_main = "summary"
     # summary_sep = lambda : ", "
 
 @dd.receiver(dd.post_startup)
