@@ -43,17 +43,18 @@ class UpdateGuests(dd.Action):
 
     def run_on_event(self, ar, obj):
 
-        # existing = set([g.partner.pk for g in obj.guest_set.all()])
+        if obj.guests_edited:
+            return
         existing = {g.partner.pk : g for g in obj.guest_set.all()}
 
-        if len(existing) and obj.can_edit_guests_manually():
-            return
+        # if len(existing) and obj.can_edit_guests_manually():
+        #     return
 
         c = u = d = 0
-        #print("20190328 existing: {}".format(existing))
+        # print("20190328 existing: {}".format(existing))
         # create suggested guest that don't exist
         for sg in obj.suggest_guests():
-            #print("20190328 suggested {}".format(sg))
+            # print("20190328 suggested {}".format(sg))
             eg = existing.pop(sg.partner.pk, None)
             if eg is None:
                 sg.save()
@@ -82,6 +83,7 @@ class UpdateAllGuests(UpdateGuests):
         for obj in ar.selected_rows:
             qs = Event.objects.filter(
                 **gfk2lookup(gfk, obj, state__in=states))
+
             def ok(ar2):
                 for e in qs:
                     self.run_on_event(ar, e)
@@ -95,8 +97,8 @@ class UpdateAllGuests(UpdateGuests):
 class RefuseGuestStates(dd.ChangeStateAction):
 
     """Mixin for transition actions on calendar entries that refuse to execute
-    when at least one guest is in a guest state which is forbidden for the
-    target entry state.
+    when at least one guest is in a guest state that is forbidden for the target
+    entry state.
 
     If at least one guest with one of the refused states is found, Lino raises a
     user warning.
@@ -106,8 +108,8 @@ class RefuseGuestStates(dd.ChangeStateAction):
     refuse_guest_states = None
     """Either None or a string with a space-separated list of the guest states to refuse.
 
-    If it is a string, it will be converted into a set of gest state objects at
-    startup.
+    If this is a string, it will be resolved into a set of guest state objects
+    at startup.
 
     """
 
