@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2011-2020 Rumma & Ko Ltd
+# Copyright 2011-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from collections import OrderedDict
@@ -235,7 +235,7 @@ class TasksByController(Tasks):
     column_names = 'priority start_date summary workflow_buttons id'
     # hidden_columns = set('owner_id owner_type'.split())
     auto_fit_column_widths = True
-    display_mode = "summary"
+    display_mode_main = "summary"
 
 
 
@@ -272,7 +272,7 @@ class TasksByProject(Tasks):
     required_roles = dd.login_required((OfficeUser, OfficeOperator))
     master_key = 'project'
     column_names = 'priority start_date user summary owner workflow_buttons *'
-    display_mode = "summary"
+    display_mode_main = "summary"
 
 
 class GuestRoles(dd.Table):
@@ -439,7 +439,7 @@ class GuestsByPartner(Guests):
     # required_roles = dd.login_required(OfficeUser)
     column_names = 'event__when_text event_summary event__user role workflow_buttons *'
     auto_fit_column_widths = True
-    display_mode = "summary"
+    display_mode_main = "summary"
     order_by = ['-event__start_date', '-event__start_time']
 
     @classmethod
@@ -992,7 +992,7 @@ class EntriesByController(Events):
     column_names = 'when_text summary workflow_buttons auto_type user event_type *'
     # column_names = 'when_text:20 when_html summary workflow_buttons *'
     auto_fit_column_widths = True
-    display_mode = "summary"
+    display_mode_main = "summary"
     order_by = ["-start_date", "-start_time", "auto_type", "id"]
     # order_by = ['seqno']
 
@@ -1034,7 +1034,7 @@ class EntriesByGuest(Events):
     summary
     event_type
     """
-    display_mode = "summary"
+    display_mode_main = "summary"
     order_by = ['-start_date', '-start_time']
 
     @classmethod
