@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2011-2021 Rumma & Ko Ltd
+# Copyright 2011-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 import datetime
@@ -10,7 +10,7 @@ from django.conf import settings
 from django.db import models
 
 from lino.api import dd, rt, _, gettext
-from lino.mixins import ObservedDateRange
+from lino.mixins import ObservedDateRange, Draggable
 from lino.core.roles import Explorer
 from lino.core.fields import TableRow
 from lino.core.tables import VentilatedColumns, AbstractTable
@@ -22,7 +22,7 @@ from lino.modlib.users.mixins import My
 from lino.modlib.office.roles import OfficeUser, OfficeStaff, OfficeOperator
 
 from lino.utils import join_elems, ONE_DAY, ONE_WEEK
-from etgen.html import E, forcetext
+from etgen.html import E, forcetext, tostring
 
 from lino_xl.lib.cal.choicelists import PlannerColumns, Weekdays
 from lino_xl.lib.cal.choicelists import DurationUnits, YearMonths
@@ -87,7 +87,12 @@ class ParameterClone(dd.Actor):
     def init_layouts(cls):
         super(ParameterClone, cls).init_layouts()
         # cls.params_layout = rt.models.cal.Events.params_layout
-        cls.params_layout = dd.plugins.calview.params_layout
+        pl = dd.plugins.calview.params_layout
+        if settings.SITE.default_ui == 'lino_react.react':
+            pl = """
+            navigation_panel
+            """ + pl
+        cls.params_layout = pl
 
     @classmethod
     def setup_parameters(cls, params):
@@ -224,7 +229,7 @@ class DayNavigator(DaysTable):
         user=dd.ForeignKey('users.User', null=True, blank=True))
     column_names = "detail_link *"
     params_panel_hidden = False
-    display_mode = "html"
+    display_mode_main = "html"
     # hide_top_toolbar = True
     planner = None  # must be set for concrete subclasses
 
@@ -471,6 +476,12 @@ class DaySlave(AbstractTable):
         #         yield obj
         # return super(DaySlave, cls).get_request_queryset(ar, **filter)
 
+    @classmethod
+    def update_row_meta(cls, today, ar):
+        if 'calDates' not in ar.row_meta:
+            ar.row_meta['calDates'] = [None for i in range(8)]
+        ar.row_meta['calDates'][today.weekday() + 1] = today.isoformat()
+
     @classmethod
     def unused_get_calview_chunks(cls, self, ar):
         """
@@ -509,18 +520,18 @@ class DaySlave(AbstractTable):
         text = E.span(time_text, " ", *obj.get_event_summary(ar))
         color = obj.get_display_color()
         if color:
-            style = "background-color: {}; color: {}; ".format(color.value, color.font_color)
+            style = "overflow: hidden; background-color: {}; color: {}; ".format(color.value, color.font_color)
             if passed_style:
                 style += passed_style
             if mde:
                 style += " height: 1.2em;"
-                return E.div(text, style=style)
+                return E.div(text, style=style, pk=str(obj.pk))
             dot  = E.span("\u00A0", CLASS="dot", style=style)
             # ele.attrib['style'] = "color: white;background-color: {};".format(data_color)
             # dot.attrib['style'] = "background-color: {};".format(data_color)
-            return E.div(dot, text, style="height: 1.2em;padding: 0 5px")
+            return E.div(dot, text, style="overflow: hidden; height: 1.2em;padding: 0 5px", pk=str(obj.pk))
         else:
-            return E.div(text, style="height: 1.2em;padding: 0 5px")
+            return E.div(text, style="overflow: hidden; height: 1.2em;padding: 0 5px", pk=str(obj.pk))
 
 
 class DailySlaveBase(DaySlave, VentilatedColumns):
@@ -572,8 +583,9 @@ class DailySlaveBase(DaySlave, VentilatedColumns):
             #                        start_time__isnull=False)
             qs = qs.order_by('start_date', 'start_time')
             chunks = [e.obj2href(ar, cls.get_calview_div(e, ar)) for e in qs]
-            return E.table(E.tr(E.td(E.div(*join_elems(chunks),
-                style="overflow: visible;"))), CLASS="fixed-table")
+            # return E.table(E.tr(E.td(E.div(*join_elems(chunks),
+            #     style="overflow: visible;"))), CLASS="fixed-table")
+            return tostring(chunks)
 
         return dd.VirtualField(dd.HtmlBox(pc.text), func)
 
@@ -614,14 +626,19 @@ class WeeklySlaveBase(DaySlave, VentilatedColumns):
             # current_week_day = current_day + \
             #     timedelta(days=int(week_day.value) - current_day.weekday() - 1)
             # qs = qs.filter(start_date=today)
+
+            cls.update_row_meta(today, ar)
+
             qs = qs.filter(start_date=today)
             qs = qs.order_by('start_time')
+            ides = None
             if obj is cls.model.HEADER_ROW:
                 chunks = obj.get_header_chunks(ar, qs, today)
             else:
                 chunks = obj.get_weekly_chunks(ar, qs, today)
-            return E.table(E.tr(E.td(E.div(*join_elems(chunks),
-                style="overflow: visible;"))), CLASS="fixed-table")
+            # return E.table(E.tr(E.td(E.div(*join_elems(chunks),
+            #     style="overflow: visible;"))), CLASS="fixed-table")
+            return tostring(chunks)
 
         return dd.VirtualField(dd.HtmlBox(week_day.text), func)
 
@@ -669,6 +686,9 @@ class MonthlySlaveBase(DaySlave, VentilatedColumns):
             # target_day = week[int(wd.value)-1]
             # qs = qs.filter(start_date=target_day.date)
             today = target_day.date
+
+            cls.update_row_meta(today, ar)
+
             qs = qs.filter(start_date=today)
             qs = qs.order_by('start_time')
 
@@ -748,18 +768,22 @@ class MonthlySlaveBase(DaySlave, VentilatedColumns):
                 header_items.append(btn)
 
             header = E.div(*header_items, align="center", CLASS="header" )
-            return E.table(E.tr(E.td(*[header, E.div(*join_elems(chunks), style="overflow: visible;")])),
-                           CLASS="fixed-table cal-month-cell {} {} {}".format(
-                             "current-month" if current_month == target_day.date.month else "other-month",
-                             "current-day" if target_day.date == today else "",
-                             "cal-in-past" if target_day.date < today else ""
-                         ))
+            # return E.table(E.tr(E.td(*[header, E.div(*join_elems(chunks), style="overflow: visible;")])),
+            #                CLASS="fixed-table cal-month-cell {} {} {}".format(
+            #                  "current-month" if current_month == target_day.date.month else "other-month",
+            #                  "current-day" if target_day.date == today else "",
+            #                  "cal-in-past" if target_day.date < today else ""
+            #              ))
+
+            chunks.insert(0, header)
+
+            return tostring(chunks)
 
         return dd.VirtualField(dd.HtmlBox(wd.text), func)
 
 
 class DailyPlanner(ParameterClone, DailySlaveBase, DailyPlannerRows):
-    # display_mode = "html"
+    # display_mode_main = "html"
     navigation_mode = 'day'
 
 class DailySlave(DailyPlanner):
@@ -770,7 +794,7 @@ class DailySlave(DailyPlanner):
 class WeeklySlave(ParameterClone, WeeklySlaveBase, DailyPlannerRows):
     # model = 'calview.DailyPlannerRow'
     # required_roles = dd.login_required(OfficeStaff)
-    # display_mode = "html"
+    # display_mode_main = "html"
 
     title = _("Planner")
 
