@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2012-2020 Rumma & Ko Ltd
+# Copyright 2012-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 
@@ -632,7 +632,7 @@ class EnrolmentsByCourse(Enrolments):
                    'remark workflow_buttons *'
     auto_fit_column_widths = True
     # cell_edit = False
-    display_mode = 'html'
+    display_mode_main = 'html'
 
     insert_layout = """
     pupil
