@@ -3,7 +3,7 @@
 """
 Adds functionality for managing "milestones" and "deployments".
 
-See :doc:`/specs/noi/deploy`.
+See :doc:`/specs/deploy`.
 
 """
 
@@ -34,7 +34,7 @@ class Plugin(ad.Plugin):
         m = m.add_menu(p.app_label, p.verbose_name)
         # m.add_action('deploy.Milestones')
         m.add_action('deploy.Deployments')
-        
+
     # def get_dashboard_items(self, user):
     #     if user.authenticated:
     #         yield self.site.models.deploy.MyMilestones
