@@ -1,35 +1,21 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2016-2020 Rumma & Ko Ltd
+# Copyright 2016-2021 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 import re
+from os.path import join, dirname
 
 from django.conf import settings
 
 from lino.api import dd, rt, _
+from lino.modlib.printing.actions import WriteXmlAction
+from lino_xl.lib.finan.validate import validate_pain001
 
-from lino.modlib.printing.mixins import DirectPrintAction
-from etgen.sepa.validate import validate_pain001
-
-class WriteXML(DirectPrintAction):
-    """Generate an XML file from this database object.
-
-    """
-    combo_group = "writexml"
-    label = _("XML")
-
-    build_method = "xml"
-    icon_name = None
-    # show_in_bbar = False
-
-
-class WritePaymentsInitiation(WriteXML):
-    """Generate an XML file (SEPA payment initiation) from this database
-object.
-
-    """
+class WritePaymentsInitiation(WriteXmlAction):
+    # Instantiated as lino.xl.lib.finan.PaymentOrder.write_xml
 
     tplname = "pain_001"
+    xsdfile = join(dirname(__file__), 'XSD', 'pain.001.001.02.xsd')
 
     def get_printable_context(self, bm, elem, ar):
         context = super(
@@ -65,10 +51,10 @@ object.
 
         return super(WritePaymentsInitiation, self).before_build(bm, elem)
 
-    def validate_result_file(self, filename):
-        try:
-            validate_pain001(filename)
-        except Exception as e:
-            raise Warning(_(
-                "Oops, the generated XML file {} is invalid: {}").format(
-                    filename, e))
+    # def validate_result_file(self, filename):
+    #     try:
+    #         validate_pain001(filename)
+    #     except Exception as e:
+    #         raise Warning(_(
+    #             "Oops, the generated XML file {} is invalid: {}").format(
+    #                 filename, e))
