@@ -32,7 +32,7 @@ class Models(dd.VirtualTable):
     about.FieldsByModel
     """
 
-    display_mode = 'html'
+    display_mode_main = 'html'
 
     @classmethod
     def get_data_rows(self, ar):
@@ -140,7 +140,7 @@ class Inspector(dd.VirtualTable):
     )
     params_layout = 'inspected show_callables'
     # editable = False
-    # display_mode = 'html'
+    # display_mode_main = 'html'
 
     @classmethod
     def get_inspected(self, name):
