@@ -4,6 +4,8 @@
 
 
 from django.db import models
+from django.db.models import Q
+from django.conf import settings
 
 from etgen.html import E
 from lino.utils import SumCollector
@@ -13,35 +15,8 @@ from lino.api import dd, rt, _
 from .choicelists import VoucherTypes, TradeTypes, VoucherStates
 from .roles import LedgerUser
 
-
-if dd.is_installed('ledger'):
-    project_model = dd.plugins.ledger.project_model
-else:
-    project_model = None
-
-
-class CashPayable(dd.Model):
-
-    receivable_field = None
-
-    class Meta:
-        abstract = True
-
-    cash_received = dd.PriceField(_("Cash received"), default="0.0")
-
-    @dd.displayfield(_("Cash to return"))
-    def cash_to_return(self, ar):
-        return self.returnable_cash_amount(ar)
-
-    def returnable_cash_amount(self, ar):
-        if self.receivable_field is None:
-            raise NotImplementedError
-        receivable = getattr(self, self.receivable_field)
-        if receivable is not None and self.cash_received >= receivable:
-            return self.cash_received - receivable
-
-    def get_default_payment_method(self, ar=None):
-        return rt.models.ledger.PaymentMethod.objects.filter(journal=self.journal).first()
+project_model = dd.get_plugin_setting('ledger', 'project_model', None)
+has_payment_methods = dd.get_plugin_setting('ledger', 'has_payment_methods', False)
 
 
 class ProjectRelated(dd.Model):
@@ -73,9 +48,14 @@ class PartnerRelated(dd.Model):
         'ledger.PaymentTerm',
         related_name="%(app_label)s_%(class)s_set_by_payment_term",
         blank=True, null=True)
-    payment_method = dd.ForeignKey(
-        'ledger.PaymentMethod',
-        blank=True, null=True)
+
+    if has_payment_methods:
+        payment_method = dd.ForeignKey(
+            'ledger.PaymentMethod',
+            blank=True, null=True)
+
+    def get_payment_term(self):
+        return self.payment_term
 
     def get_partner(self):
         """Overrides Voucher.get_partner"""
@@ -111,6 +91,11 @@ class PartnerRelated(dd.Model):
             self.payment_term = self.partner.payment_term
             if self.payment_term:
                 self.payment_term_changed()
+        if has_payment_methods:
+            if not self.payment_method:
+                self.payment_method = rt.models.ledger.PaymentMethod.objects.order_by('id').first()
+                # self.payment_method = rt.models.ledger.PaymentMethod.objects.filter(
+                #     Q(journal__isnull=True)|Q(journal=self.journal)).order_by('id').first()
 
     def payment_term_changed(self, ar=None):
         if self.payment_term:
@@ -122,8 +107,16 @@ class PartnerRelated(dd.Model):
     #     if self.payment_term:
     #         self.due_date = self.payment_term.get_due_date(self.entry_date)
 
+class CashPayable(dd.Model):
 
-class Payable(PartnerRelated):
+    receivable_field = None
+
+    class Meta:
+        abstract = True
+
+
+
+class Payable(dd.Model):
     class Meta:
         abstract = True
 
@@ -132,14 +125,17 @@ class Payable(PartnerRelated):
     due_date = models.DateField(_("Due date"), blank=True, null=True)
     # title = models.CharField(_("Description"), max_length=200, blank=True)
 
+    def get_payment_term(self):
+        return None
+
     def full_clean(self):
-        if self.payment_term is None and self.partner_id is not None:
-            self.payment_term = self.partner.payment_term
         if not self.due_date:
-            if self.payment_term:
-                self.due_date = self.payment_term.get_due_date(
+            payment_term = self.get_payment_term()
+            if payment_term:
+                self.due_date = payment_term.get_due_date(
                     self.voucher_date or self.entry_date)
-        super(Payable, self).full_clean()
+        # super(Payable, self).full_clean()
+        super().full_clean()
 
     @classmethod
     def get_registrable_fields(cls, site):
@@ -207,18 +203,17 @@ class Payable(PartnerRelated):
                 match=self.get_match())
 
         if dd.plugins.ledger.worker_model \
-                and TradeTypes.clearings.main_account \
-                and self.payment_term_id and self.payment_term.worker:
-            worker = self.payment_term.worker
-            # one movement to nullify the credit that was booked to the partner account,
-            # another movment to book it to the worker's account:
-            yield self.create_movement(
-                None, (acc, None), None, total_amount,
-                partner=partner, match=self.get_match())
-            yield self.create_movement(
-                None, (TradeTypes.clearings.get_main_account(), None), None, -total_amount,
-                partner=worker, match=self.get_match())
-
+                and TradeTypes.clearings.main_account:
+            payment_term = self.get_payment_term()
+            if payment_term and payment_term.worker:
+                # one movement to nullify the credit that was booked to the partner account,
+                # another movment to book it to the worker's account:
+                yield self.create_movement(
+                    None, (acc, None), None, total_amount,
+                    partner=partner, match=self.get_match())
+                yield self.create_movement(
+                    None, (TradeTypes.clearings.get_main_account(), None), None, -total_amount,
+                    partner=payment_term.worker, match=self.get_match())
 
 
 class Matching(dd.Model):
