@@ -33,10 +33,12 @@ from lino_xl.lib.excerpts.mixins import Certifiable
 from .utils import myround
 from .choicelists import CommonAccounts
 from .choicelists import DC, PeriodStates
-from .mixins import ProjectRelated, VoucherNumber, PeriodRange, PeriodRangeObservable, Payable
+from .mixins import ProjectRelated, VoucherNumber, PeriodRange, PeriodRangeObservable, PartnerRelated, Payable
 from .roles import VoucherSupervisor
 from .ui import *
 
+has_payment_methods = dd.get_plugin_setting('ledger', 'has_payment_methods', False)
+
 
 class LedgerInfo(dd.Model):
     class Meta:
@@ -446,14 +448,21 @@ class PaymentTerm(BabelNamed, Referrable):
         return d
 
 
-class PaymentMethod(BabelDesignated):
+if has_payment_methods:
+    class PaymentMethod(BabelDesignated):
 
-    class Meta:
-        app_label = 'ledger'
-        verbose_name = _("Payment method")
-        verbose_name_plural = _("Payment methods")
+        class Meta:
+            app_label = 'ledger'
+            verbose_name = _("Payment method")
+            verbose_name_plural = _("Payment methods")
 
-    journal = dd.ForeignKey('ledger.Journal')
+        # journal = dd.ForeignKey('ledger.Journal')  # not used
+
+        payment_account = dd.ForeignKey(
+            'ledger.Account', verbose_name=_("Payment account"),
+            null=True, blank=True)
+
+        is_cash = dd.BooleanField(_("Cash"), default=False)
 
 
 #
@@ -792,7 +801,8 @@ class Voucher(UserAuthored, Duplicable, UploadController, PeriodRangeObservable)
             kw['account'] = account
         kw.update(voucher=self)
         #~ logger.info("20131116 %s",self.items.model)
-        return self.items.model(**kw)
+        return self.journal.voucher_type.get_items_model()(**kw)
+        # return self.__class__.items.field.model(**kw)
         #~ return super(AccountInvoice,self).add_voucher_item(**kw)
 
     def get_bank_account(self):
@@ -925,7 +935,7 @@ class RegistrableVoucher(Registrable, Voucher):
         self.do_and_clear(doit, do_clear)
 
 
-class Declaration(Payable, RegistrableVoucher, Certifiable, PeriodRange):
+class Declaration(PartnerRelated, Payable, RegistrableVoucher, Certifiable, PeriodRange):
     class Meta:
         abstract = True
         app_label = "ledger"
