@@ -169,7 +169,7 @@ class MembersByPartner(Members):
     master_key = 'partner'
     column_names = "list remark *"
     order_by = ['list__ref']
-    display_mode = "summary"
+    display_mode_main = "summary"
     summary_sep = comma
     insert_layout = """
     list
