@@ -218,7 +218,7 @@ class NotesByX(Notes):
     abstract = True
     column_names = "date time event_type type subject user *"
     order_by = ["-date", "-time"]
-    display_mode = 'summary'
+    display_mode_main = 'summary'
     insert_layout = """
     event_type:25 type:25
     subject
