@@ -180,12 +180,18 @@ class CheckinVisitor(NotifyingAction):
             user=obj.event.user,
             partner=obj.partner)
 
+    def get_notify_body(self, ar, obj):
+        return self.get_notify_subject(ar, obj)
+
     def get_notify_recipients(self, ar, obj):
         """Yield a list of users to be notified.
 
         """
         yield (obj.event.user, obj.event.user.mail_mode)
 
+    def get_notify_owner(self, ar, obj):
+        return obj.event
+
     def run_from_ui(self, ar, **kw):
         obj = ar.selected_rows[0]  # a cal.Guest instance
 
