@@ -1,4 +1,4 @@
-# Copyright 2014-2021 Rumma & Ko Ltd
+# Copyright 2014-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """Adds functionality for handling sales.
@@ -49,4 +49,5 @@ class Plugin(ad.Plugin):
         m.add_action('sales.InvoiceItems')
 
     def get_quicklinks(self):
-        yield 'sales.VatProductInvoice.start_new_sale'
+        if self.site.get_plugin_setting('ledger', 'has_payment_methods'):
+            yield 'sales.CashInvoice.start_new_sale'
