@@ -21,7 +21,7 @@ class Plugin(ad.Plugin):
         # 'lino_noi.lib.noi',
         'lino_xl.lib.xl',
         # 'lino_xl.lib.tickets',
-        'lino_noi.lib.contacts']
+        'lino_xl.lib.contacts']
 
     # demander_model = 'tickets.Ticket'
     demander_model = 'contacts.Person'
