@@ -72,7 +72,7 @@ class SiteStates(dd.Workflow):
     is_exposed = models.BooleanField(_("Exposed"), default=False)
 
 # ⛶: 26F6 (not rendered correctly in Firefox)
-# ⚒: 2692 HAMMER AND PICK 
+# ⚒: 2692 HAMMER AND PICK
 add = SiteStates.add_item
 add('10', _("Draft"), 'draft', is_exposed=True,
     button_text = "⚹")
@@ -154,39 +154,39 @@ else:
     TicketStates.cancelled.button_text="☒"  # BALLOT BOX WITH X (U+2612)
 
 
-class LinkType(dd.Choice):
-
-    symmetric = False
-
-    def __init__(self, value, name, ptext, ctext, **kw):
-        self.ptext = ptext  # parent
-        self.ctext = ctext
-        # text = string_concat(ptext, ' (', ctext, ')')
-        text = ptext
-        super(LinkType, self).__init__(value, text, name, **kw)
-
-    def as_parent(self):
-        return self.ptext
-
-    def as_child(self):
-        return self.ctext
-
-
-class LinkTypes(dd.ChoiceList):
-    required_roles = dd.login_required(dd.SiteStaff)
-    verbose_name = _("Dependency type")
-    verbose_name_plural = _("Dependency types")
-    item_class = LinkType
-
-add = LinkTypes.add_item
-add('10', 'requires', _("Requires"), _("Required by"))
-add('20', 'triggers', _("Triggers"), _("Triggered by"))
-add('30', 'suggests', _("Suggests"), _("Suggested by"))
-add('40', 'obsoletes', _("Obsoletes"), _("Obsoleted by"))
-# add('30', 'seealso', _("See also"), _("Referred by"))
-# deprecated (use "fixed_for" field instead):
-# add('40', 'deploys', _("Deploys"), _("Deployed by"))
-# will replace FK field "duplicate_of"):
-add('50', 'duplicates', _("Duplicates"), _("Duplicate of"))
-
-# LinkTypes.addable_types = [LinkTypes.requires, LinkTypes.duplicates]
+# class LinkType(dd.Choice):
+#
+#     symmetric = False
+#
+#     def __init__(self, value, name, ptext, ctext, **kw):
+#         self.ptext = ptext  # parent
+#         self.ctext = ctext
+#         # text = string_concat(ptext, ' (', ctext, ')')
+#         text = ptext
+#         super(LinkType, self).__init__(value, text, name, **kw)
+#
+#     def as_parent(self):
+#         return self.ptext
+#
+#     def as_child(self):
+#         return self.ctext
+#
+#
+# class LinkTypes(dd.ChoiceList):
+#     required_roles = dd.login_required(dd.SiteStaff)
+#     verbose_name = _("Dependency type")
+#     verbose_name_plural = _("Dependency types")
+#     item_class = LinkType
+#
+# add = LinkTypes.add_item
+# add('10', 'requires', _("Requires"), _("Required by"))
+# add('20', 'triggers', _("Triggers"), _("Triggered by"))
+# add('30', 'suggests', _("Suggests"), _("Suggested by"))
+# add('40', 'obsoletes', _("Obsoletes"), _("Obsoleted by"))
+# # add('30', 'seealso', _("See also"), _("Referred by"))
+# # deprecated (use "fixed_for" field instead):
+# # add('40', 'deploys', _("Deploys"), _("Deployed by"))
+# # will replace FK field "duplicate_of"):
+# add('50', 'duplicates', _("Duplicates"), _("Duplicate of"))
+#
+# # LinkTypes.addable_types = [LinkTypes.requires, LinkTypes.duplicates]
