@@ -14,7 +14,8 @@ from lino.utils import join_elems
 from lino.core.gfks import gfk2lookup
 
 from lino_xl.lib.cal.mixins import daterange_text
-from .choicelists import TicketEvents, TicketStates, LinkTypes, Priorities, SiteStates
+from .choicelists import TicketEvents, TicketStates, Priorities, SiteStates
+# from .choicelists import LinkTypes
 from .roles import TicketsReader, Reporter, Searcher, Triager, TicketsStaff
 
 site_model = dd.plugins.tickets.site_model
@@ -139,123 +140,123 @@ class TicketTypes(dd.Table):
 #     column_names = "ref name *"
 
 
-class Links(dd.Table):
-    model = 'tickets.Link'
-    required_roles = dd.login_required(TicketsStaff)
-    stay_in_grid = True
-    detail_layout = dd.DetailLayout("""
-    parent
-    type
-    child
-    """, window_size=(40, 'auto'))
-
-    insert_layout = """
-    parent
-    type
-    child
-    """
+# class Links(dd.Table):
+#     model = 'tickets.Link'
+#     required_roles = dd.login_required(TicketsStaff)
+#     stay_in_grid = True
+#     detail_layout = dd.DetailLayout("""
+#     parent
+#     type
+#     child
+#     """, window_size=(40, 'auto'))
+#
+#     insert_layout = """
+#     parent
+#     type
+#     child
+#     """
+#
 
 
-
-class LinksByTicket(Links):
-    label = _("Dependencies")
-    required_roles = dd.login_required(Triager)
-    master = 'tickets.Ticket'
-    column_names = 'parent type_as_parent:10 child'
-    display_mode_main = 'summary'
-
-    @classmethod
-    def get_request_queryset(self, ar):
-        mi = ar.master_instance  # a Person
-        if mi is None:
-            return
-        Link = rt.models.tickets.Link
-        flt = Q(parent=mi) | Q(child=mi)
-        return Link.objects.filter(flt).order_by(
-            'child__modified', 'parent__modified')
-
-    @classmethod
-    def get_table_summary(self, obj, ar):
-        """The :meth:`summary view <lino.core.actors.Actor.get_table_summary>`
-        for :class:`LinksByTicket`.
-
-        """
-        # if obj.pk is None:
-        #     return ''
-        #     raise Exception("20150218")
-        sar = self.request_from(ar, master_instance=obj)
-        links = []
-        for lnk in sar:
-            if lnk.parent is None or lnk.child is None:
-                pass
-            else:
-                if lnk.child_id == obj.id:
-                    i = (lnk.type.as_child(), lnk.parent)
-                else:
-                    i = (lnk.type.as_parent(), lnk.child)
-                links.append(i)
-
-        def by_age(a):
-            return a[1].modified
-
-        try:
-            links.sort(key=by_age)
-        # except AttributeError:
-        except (AttributeError, ValueError):
-            # AttributeError: 'str' object has no attribute 'as_date'
-            # possible when empty birth_date
-            # ValueError: day is out of range for month
-            pass
-
-        tbt = dict()  # tickets by lnktype
-        for lnktype, other in links:
-            lst = tbt.setdefault(lnktype, [])
-            # txt = "#%d" % other.id
-            lst.append(other.obj2href(ar))
-
-        items = []
-        for lnktype, lst in tbt.items():
-            items.append(E.li(str(lnktype), ": ", *join_elems(lst, ', ')))
-        elems = []
-        if len(items) > 0:
-            # elems += join_elems(items)
-            # elems.append(l(*items))
-            elems.append(E.ul(*items))
-        # else:
-        #     elems.append(_("No dependencies."))
-
-        # Buttons for creating relationships:
-
-        sar = obj.spawn_ticket.request_from(ar)
-        if ar.renderer.is_interactive and sar.get_permission():
-            btn = sar.ar2button(obj)
-            elems += [E.br(), btn]
-
-        if self.insert_action is not None and ar.renderer.is_interactive:
-            sar = self.insert_action.request_from(ar)
-            if sar.get_permission():
-                actions = []
-                for lt in LinkTypes.objects():
-                    actions.append(E.br())
-                    sar.known_values.update(type=lt, parent=obj)
-                    sar.known_values.pop('child', None)
-                    sar.clear_cached_status()
-                    btn = sar.ar2button(None, lt.as_parent(), icon_name=None)
-                    if not lt.symmetric:
-                        # actions.append('/')
-                        sar.known_values.update(type=lt, child=obj)
-                        sar.known_values.pop('parent', None)
-                        sar.clear_cached_status()
-                        btn2 = sar.ar2button(None, lt.as_child(), icon_name=None)
-                        # actions.append(btn)
-                        btn = E.span(btn, '/', btn2)
-                    actions.append(btn)
-                    # actions.append(' ')
-                # actions = join_elems(actions, E.br)
-
-                if len(actions) > 0:
-                    elems += [E.br(), gettext("Create dependency as ")] + actions
-        return E.div(*elems)
+# class LinksByTicket(Links):
+#     label = _("Dependencies")
+#     required_roles = dd.login_required(Triager)
+#     master = 'tickets.Ticket'
+#     column_names = 'parent type_as_parent:10 child'
+#     display_mode_main = 'summary'
+#
+#     @classmethod
+#     def get_request_queryset(self, ar):
+#         mi = ar.master_instance  # a Person
+#         if mi is None:
+#             return
+#         Link = rt.models.tickets.Link
+#         flt = Q(parent=mi) | Q(child=mi)
+#         return Link.objects.filter(flt).order_by(
+#             'child__modified', 'parent__modified')
+#
+#     @classmethod
+#     def get_table_summary(self, obj, ar):
+#         """The :meth:`summary view <lino.core.actors.Actor.get_table_summary>`
+#         for :class:`LinksByTicket`.
+#
+#         """
+#         # if obj.pk is None:
+#         #     return ''
+#         #     raise Exception("20150218")
+#         sar = self.request_from(ar, master_instance=obj)
+#         links = []
+#         for lnk in sar:
+#             if lnk.parent is None or lnk.child is None:
+#                 pass
+#             else:
+#                 if lnk.child_id == obj.id:
+#                     i = (lnk.type.as_child(), lnk.parent)
+#                 else:
+#                     i = (lnk.type.as_parent(), lnk.child)
+#                 links.append(i)
+#
+#         def by_age(a):
+#             return a[1].modified
+#
+#         try:
+#             links.sort(key=by_age)
+#         # except AttributeError:
+#         except (AttributeError, ValueError):
+#             # AttributeError: 'str' object has no attribute 'as_date'
+#             # possible when empty birth_date
+#             # ValueError: day is out of range for month
+#             pass
+#
+#         tbt = dict()  # tickets by lnktype
+#         for lnktype, other in links:
+#             lst = tbt.setdefault(lnktype, [])
+#             # txt = "#%d" % other.id
+#             lst.append(other.obj2href(ar))
+#
+#         items = []
+#         for lnktype, lst in tbt.items():
+#             items.append(E.li(str(lnktype), ": ", *join_elems(lst, ', ')))
+#         elems = []
+#         if len(items) > 0:
+#             # elems += join_elems(items)
+#             # elems.append(l(*items))
+#             elems.append(E.ul(*items))
+#         # else:
+#         #     elems.append(_("No dependencies."))
+#
+#         # Buttons for creating relationships:
+#
+#         sar = obj.spawn_ticket.request_from(ar)
+#         if ar.renderer.is_interactive and sar.get_permission():
+#             btn = sar.ar2button(obj)
+#             elems += [E.br(), btn]
+#
+#         if self.insert_action is not None and ar.renderer.is_interactive:
+#             sar = self.insert_action.request_from(ar)
+#             if sar.get_permission():
+#                 actions = []
+#                 for lt in LinkTypes.objects():
+#                     actions.append(E.br())
+#                     sar.known_values.update(type=lt, parent=obj)
+#                     sar.known_values.pop('child', None)
+#                     sar.clear_cached_status()
+#                     btn = sar.ar2button(None, lt.as_parent(), icon_name=None)
+#                     if not lt.symmetric:
+#                         # actions.append('/')
+#                         sar.known_values.update(type=lt, child=obj)
+#                         sar.known_values.pop('parent', None)
+#                         sar.clear_cached_status()
+#                         btn2 = sar.ar2button(None, lt.as_child(), icon_name=None)
+#                         # actions.append(btn)
+#                         btn = E.span(btn, '/', btn2)
+#                     actions.append(btn)
+#                     # actions.append(' ')
+#                 # actions = join_elems(actions, E.br)
+#
+#                 if len(actions) > 0:
+#                     elems += [E.br(), gettext("Create dependency as ")] + actions
+#         return E.div(*elems)
 
 
 class TicketDetail(dd.DetailLayout):
@@ -278,7 +279,7 @@ class TicketDetail(dd.DetailLayout):
 
     more = dd.Panel("""
     more1 DuplicatesByTicket:20
-    description:40 upgrade_notes:20 LinksByTicket:20
+    description:40 upgrade_notes:20 #LinksByTicket:20
     """, label=_("More"))
 
     more1 = """
