@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2012-2021 Rumma & Ko Ltd
+# Copyright 2012-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from decimal import Decimal
@@ -22,7 +22,7 @@ from lino.api import dd, rt, _
 from lino_xl.lib.ledger.choicelists import CommonAccounts
 from lino_xl.lib.ledger.choicelists import TradeTypes
 from lino_xl.lib.ledger.mixins import ProjectRelated, VoucherItem
-from lino_xl.lib.ledger.mixins import Payable
+from lino_xl.lib.ledger.mixins import Payable, PartnerRelated
 from lino_xl.lib.ledger.models import RegistrableVoucher, VoucherStates
 from lino_xl.lib.ledger.utils import ZERO, ONE, myround
 
@@ -296,19 +296,19 @@ class VatDocument(RegistrableVoucher, ProjectRelated, VatTotal):
             # invoice, Lino must not automatically replace the account
             # of that invoice.
 
-        elif new.name == 'draft':
-            if not self.edit_totals:
-                self.total_base = None
-                self.total_vat = None
-                self.total_incl = None
-            else:
-                self.compute_totals()
+        # elif new.name == 'draft':
+        #     if not self.edit_totals:
+        #         self.total_base = None
+        #         self.total_vat = None
+        #         self.total_incl = None
+        #     else:
+        #         self.compute_totals()
         super(VatDocument, self).before_state_change(ar, old, new)
 
 # dd.update_field(VatDocument, 'total_incl', verbose_name=_("Total to pay"))
 
 
-class VatVoucher(VatDocument, Payable):
+class VatVoucher(VatDocument, PartnerRelated, Payable):
     # todo: merge VatDocument and VatVoucher?
     class Meta:
         abstract = True
