@@ -19,15 +19,8 @@ class VoteAction(dd.Action):
 
 
 class CreateVote(VoteAction):
-    """Define your vote about this object.
-
-    visible only when you don't yet have a vote on this
-    object. Clicking it will create a default vote object and show
-    that object in a detail window.
-
-    """
     sort_index = 100
-    button_text  = u"☆"  # 2606
+    button_text  = "☆"  # 2606
     show_in_workflow = True
     show_in_bbar = False
     required_roles = dd.login_required(SimpleVotesUser)
@@ -39,7 +32,7 @@ class CreateVote(VoteAction):
     # state
     # comment
     # """, window_size=(50, 12))
-    
+
 
     def get_action_permission(self, ar, obj, state):
         if not super(CreateVote, self).get_action_permission(ar, obj, state):
@@ -58,27 +51,25 @@ class CreateVote(VoteAction):
 
         # if pv.comment:
         #     create_row(
-        #         rt.models.comments.Comment, 
+        #         rt.models.comments.Comment,
         #         owner=obj,
         #         short_text=pv.comment, user=ar.get_user())
-        
+
         self.goto_vote(vote, ar)
 
+
 class EditVote(VoteAction):
     sort_index = 100
-    button_text = u"★"  # 2605
+    button_text = "★"  # 2605
     show_in_workflow = True
     show_in_bbar = False
     required_roles = dd.login_required(SimpleVotesUser)
 
     def run_from_ui(self, ar, **kw):
         self.goto_vote(ar.selected_rows[0], ar)
-        
 
 
 class VotableEditVote(EditVote):
-    """Edit your vote about this object.
-    """
     def get_action_permission(self, ar, obj, state):
         if not super(VotableEditVote, self).get_action_permission(ar, obj, state):
             return False
@@ -90,9 +81,6 @@ class VotableEditVote(EditVote):
         vote = obj.get_favourite(ar.get_user())
         # print(20170116, vote)
         self.goto_vote(vote, ar)
-        
+
         # da = rt.models.votes.VotesByVotable.detail_action
         # ar.goto_instance(vote, detail_action=da)
-
-
-
