@@ -1,6 +1,8 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2011-2020 Rumma & Ko Ltd
+# Copyright 2011-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
+import datetime as dt
+from copy import copy
 
 from django.conf import settings
 from django.db import models
@@ -449,9 +451,13 @@ def inject_summary_fields(sender, **kw):
             def getter(obj, ar):
                 qs = SiteSummary.objects.filter(
                     master=obj, year__isnull=True)
-                d = qs.aggregate(**{k:models.Sum(k)})
-                n = d[k]
-                return n
+                # d = qs.aggregate(**{k:models.Sum(k)})
+                start_date_time = dt.datetime.now()
+                end_date_time = copy(start_date_time)
+                for obj in qs:
+                    td = getattr(obj, k).as_timedelta()
+                    end_date_time += td
+                return end_date_time - start_date_time
             return getter
 
         dd.inject_field(
