@@ -162,7 +162,7 @@ class SessionsByTicket(Sessions):
     master_key = 'ticket'
     column_names = 'start_date summary start_time end_time  '\
                    'break_time duration user is_fixing *'
-    display_mode = 'summary'
+    display_mode_main = 'summary'
 
     @classmethod
     def get_table_summary(self, obj, ar):
@@ -760,7 +760,7 @@ class MySessionsByDay(MySessionsByDate):
 #class MySessionsByDay(MySessionsByDate, DaySlave):
     # with_header_row = False
     master = 'working.Day'
-    # display_mode = "html"
+    # display_mode_main = "html"
     # use_detail_params_value = True
 
     @classmethod
